# -*- coding: utf-8 -*-
"""
    :copyright: Copyright 2013-2014 by Łukasz Mierzwa
    :contact: l.mierzwa@gmail.com
"""


class ExitCodes:

    ok = 0

    command_error = 1

    notfound_error = 2

    missing_config = 3

    user_error = 4

    auth_error = 5
